@@ -1,6 +1,7 @@
 #' The Gamma distribution
 #'
-#' \lifecycle{stable}
+#' @description
+#' `r lifecycle::badge('stable')`
 #'
 #' Several important distributions are special cases of the Gamma
 #' distribution. When the shape parameter is `1`, the Gamma is an
@@ -18,9 +19,7 @@
 #'
 #' @details
 #'
-#'   We recommend reading this documentation on
-#'   <https://pkg.mitchelloharawild.com/distributional/>, where the math
-#'   will render nicely.
+#' `r pkgdown_doc_link("dist_gamma")`
 #'
 #'   In the following, let \eqn{X} be a Gamma random variable
 #'   with parameters
@@ -79,8 +78,11 @@
 #'
 #' @name dist_gamma
 #' @export
-dist_gamma <- function(shape, rate){
+dist_gamma <- function(shape, rate = 1/scale, scale = 1/rate){
   shape <- vec_cast(shape, double())
+  if(missing(rate) && missing(scale)) {
+    abort("Either the `rate` or `scale` must be specified for Gamma distributions.")
+  }
   rate <- vec_cast(rate, double())
   if(any(shape[!is.na(shape)] < 0)){
     abort("The shape parameter of a Gamma distribution must be non-negative.")
@@ -88,12 +90,7 @@ dist_gamma <- function(shape, rate){
   if(any(rate[!is.na(rate)] <= 0)){
     abort("The rate parameter of a Gamma distribution must be strictly positive.")
   }
-  new_dist(shape = shape, rate = rate, class = "dist_gamma")
-}
-
-#' @export
-print.dist_gamma <- function(x, ...){
-  cat(format(x, ...))
+  new_dist(shape = shape, rate = 1/scale, class = "dist_gamma")
 }
 
 #' @export
@@ -136,7 +133,7 @@ mean.dist_gamma <- function(x, ...){
 }
 
 #' @export
-variance.dist_gamma <- function(x, ...){
+covariance.dist_gamma <- function(x, ...){
   x[["shape"]] / x[["rate"]]^2
 }
 
